@@ -358,22 +358,24 @@ class Writer(object):
             except UnknownColumns as exc:
                 self._columns.extend(exc.unknown_columns)
                 self._init_prewrite()
-                self._write_fn(row, style, redo=True)
+                self._write_fn(row, style)
 
     def _get_last_summary_length(self):
         last_summary = self._last_summary
         return len(last_summary.splitlines()) if last_summary else 0
 
-    def _write_update(self, row, style=None, redo=False):
+    def _write_update(self, row, style=None):
         last_summary_len = self._get_last_summary_length()
-        if last_summary_len > 0 and not redo:
+
+        content, status, summary = self._content.update(row, style)
+
+        if last_summary_len > 0:
             # Clear the summary because 1) it has very likely changed, 2)
             # it makes the counting for row updates simpler, 3) and it is
             # possible for the summary lines to shrink.
             lgr.debug("Clearing summary of %d line(s)", last_summary_len)
             self._stream.clear_last_lines(last_summary_len)
 
-        content, status, summary = self._content.update(row, style)
 
         single_row_updated = False
         if isinstance(status, int):
@@ -409,7 +411,7 @@ class Writer(object):
         self._last_content_len = len(self._content)
         self._last_summary = summary
 
-    def _write_incremental(self, row, style=None, redo=False):
+    def _write_incremental(self, row, style=None):
         content, status, summary = self._content.update(row, style)
         if isinstance(status, int):
             lgr.debug("Duplicating line %d with %r", status, row)
@@ -418,7 +420,7 @@ class Writer(object):
         self._stream.write(content)
         self._last_summary = summary
 
-    def _write_final(self, row, style=None, redo=False):
+    def _write_final(self, row, style=None):
         _, _, summary = self._content.update(row, style)
         self._last_summary = summary
 
